Subject: [bug#54539] [PATCH v2 25/30] gnu: xml: Autoload unless used by Guix.

From: Maxime Devos <[email-masked]>
Date: Sat, 3 Sep 2022 18:43:27 +0200

See first commit in the series for the procedure.
This helps with, but is not sufficient for, avoiding Java.
---
 gnu/packages/xml.scm | 47 +++++++++++++++++++++++++-------------------
 1 file changed, 27 insertions(+), 20 deletions(-)

diff --git a/gnu/packages/xml.scm b/gnu/packages/xml.scm
index c3213b8f36..337b6e2f99 100644
--- a/gnu/packages/xml.scm
+++ b/gnu/packages/xml.scm
@@ -51,26 +51,33 @@
 
 (define-module (gnu packages xml)
   #:use-module (gnu packages)
-  #:use-module (gnu packages base)
-  #:use-module (gnu packages autotools)
-  #:use-module (gnu packages check)
-  #:use-module (gnu packages compression)
-  #:use-module (gnu packages curl)
-  #:use-module (gnu packages docbook)
-  #:use-module (gnu packages documentation)
-  #:use-module (gnu packages gettext)
-  #:use-module (gnu packages glib)
-  #:use-module (gnu packages gnome)
-  #:use-module (gnu packages gnupg)
-  #:use-module (gnu packages graphviz)
-  #:use-module (gnu packages gtk)
-  #:use-module (gnu packages java)
-  #:use-module (gnu packages nss)
-  #:use-module (gnu packages perl)
-  #:use-module (gnu packages perl-check)
-  #:use-module (gnu packages python)
-  #:use-module (gnu packages tls)
-  #:use-module (gnu packages web)
+  #:autoload (gnu packages base) (gnu-make which)
+  #:autoload (gnu packages autotools)
+  (autoconf automake libltdl libtool)
+  #:autoload (gnu packages check) (python-coverage python-nose python-pytest)
+  #:use-module (gnu packages compression) ; required by "guix build -d guix"
+  #:autoload (gnu packages curl) (curl)
+  #:autoload (gnu packages docbook) (docbook-xml-4.1.2 docbook-xsl)
+  #:autoload (gnu packages gettext) (gettext-minimal)
+  #:autoload (gnu packages glib) (appstream-glib glib gobject-introspection)
+  #:use-module (gnu packages gnupg) ; required by "guix build -d guix"
+  #:autoload (gnu packages gtk) (gtk-doc/stable)
+  #:autoload (gnu packages java)
+  (icedtea-8
+   java-cglib java-classpathx-servletapi java-jdom java-joda-time java-junit
+   java-stax2-api java-testng java-woodstox-core java-xerces)
+  #:autoload (gnu packages nss) (nss)
+  #:use-module (gnu packages perl) ; required by "guix build -d guix"
+  #:autoload (gnu packages perl-check)
+  (perl-test-deep
+   perl-test-differences perl-test-manifest perl-test-pod
+   perl-test-pod-coverage)
+  #:use-module (gnu packages python) ; required by "guix build -d guix"
+  #:autoload (gnu packages tls) (gnutls openssl)
+  #:autoload (gnu packages web)
+  (perl-feed-find
+   perl-html-parser perl-html-tagset perl-html-tidy perl-html-tree perl-libwww
+   perl-uri perl-uri-fetch)
   #:use-module ((guix licenses) #:prefix license:)
   #:use-module (guix gexp)
   #:use-module (guix packages)
-- 
2.37.2